#if defined (HAVE_CONFIG_H)
#  include "config.h"
#endif
/****************************************************************************
** Meta object code from reading C++ file 'TerminalView.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.9.4)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "/pub/devel/octave/octave-6.4.0-1.x86_64/src/octave-6.4.0/libgui/qterminal/libqterminal/unix/TerminalView.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'TerminalView.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.9.4. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_TerminalView_t {
    QByteArrayData data[46];
    char stringdata0[613];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_TerminalView_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_TerminalView_t qt_meta_stringdata_TerminalView = {
    {
QT_MOC_LITERAL(0, 0, 12), // "TerminalView"
QT_MOC_LITERAL(1, 13, 16), // "interrupt_signal"
QT_MOC_LITERAL(2, 30, 0), // ""
QT_MOC_LITERAL(3, 31, 16), // "keyPressedSignal"
QT_MOC_LITERAL(4, 48, 10), // "QKeyEvent*"
QT_MOC_LITERAL(5, 59, 1), // "e"
QT_MOC_LITERAL(6, 61, 11), // "mouseSignal"
QT_MOC_LITERAL(7, 73, 6), // "button"
QT_MOC_LITERAL(8, 80, 6), // "column"
QT_MOC_LITERAL(9, 87, 4), // "line"
QT_MOC_LITERAL(10, 92, 9), // "eventType"
QT_MOC_LITERAL(11, 102, 23), // "changedFontMetricSignal"
QT_MOC_LITERAL(12, 126, 6), // "height"
QT_MOC_LITERAL(13, 133, 5), // "width"
QT_MOC_LITERAL(14, 139, 24), // "changedContentSizeSignal"
QT_MOC_LITERAL(15, 164, 16), // "configureRequest"
QT_MOC_LITERAL(16, 181, 13), // "TerminalView*"
QT_MOC_LITERAL(17, 195, 5), // "state"
QT_MOC_LITERAL(18, 201, 8), // "position"
QT_MOC_LITERAL(19, 210, 15), // "isBusySelecting"
QT_MOC_LITERAL(20, 226, 15), // "sendStringToEmu"
QT_MOC_LITERAL(21, 242, 11), // "const char*"
QT_MOC_LITERAL(22, 254, 13), // "tripleClicked"
QT_MOC_LITERAL(23, 268, 4), // "text"
QT_MOC_LITERAL(24, 273, 27), // "set_global_shortcuts_signal"
QT_MOC_LITERAL(25, 301, 14), // "processFilters"
QT_MOC_LITERAL(26, 316, 11), // "updateImage"
QT_MOC_LITERAL(27, 328, 20), // "updateLineProperties"
QT_MOC_LITERAL(28, 349, 13), // "copyClipboard"
QT_MOC_LITERAL(29, 363, 15), // "extra_interrupt"
QT_MOC_LITERAL(30, 379, 14), // "pasteClipboard"
QT_MOC_LITERAL(31, 394, 14), // "pasteSelection"
QT_MOC_LITERAL(32, 409, 9), // "selectAll"
QT_MOC_LITERAL(33, 419, 15), // "outputSuspended"
QT_MOC_LITERAL(34, 435, 9), // "suspended"
QT_MOC_LITERAL(35, 445, 12), // "setUsesMouse"
QT_MOC_LITERAL(36, 458, 9), // "usesMouse"
QT_MOC_LITERAL(37, 468, 21), // "setBracketedPasteMode"
QT_MOC_LITERAL(38, 490, 18), // "bracketedPasteMode"
QT_MOC_LITERAL(39, 509, 24), // "scrollBarPositionChanged"
QT_MOC_LITERAL(40, 534, 5), // "value"
QT_MOC_LITERAL(41, 540, 10), // "blinkEvent"
QT_MOC_LITERAL(42, 551, 16), // "blinkCursorEvent"
QT_MOC_LITERAL(43, 568, 10), // "enableBell"
QT_MOC_LITERAL(44, 579, 14), // "swapColorTable"
QT_MOC_LITERAL(45, 594, 18) // "tripleClickTimeout"

    },
    "TerminalView\0interrupt_signal\0\0"
    "keyPressedSignal\0QKeyEvent*\0e\0mouseSignal\0"
    "button\0column\0line\0eventType\0"
    "changedFontMetricSignal\0height\0width\0"
    "changedContentSizeSignal\0configureRequest\0"
    "TerminalView*\0state\0position\0"
    "isBusySelecting\0sendStringToEmu\0"
    "const char*\0tripleClicked\0text\0"
    "set_global_shortcuts_signal\0processFilters\0"
    "updateImage\0updateLineProperties\0"
    "copyClipboard\0extra_interrupt\0"
    "pasteClipboard\0pasteSelection\0selectAll\0"
    "outputSuspended\0suspended\0setUsesMouse\0"
    "usesMouse\0setBracketedPasteMode\0"
    "bracketedPasteMode\0scrollBarPositionChanged\0"
    "value\0blinkEvent\0blinkCursorEvent\0"
    "enableBell\0swapColorTable\0tripleClickTimeout"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_TerminalView[] = {

 // content:
       7,       // revision
       0,       // classname
       0,    0, // classinfo
      28,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
      10,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,  154,    2, 0x06 /* Public */,
       3,    1,  155,    2, 0x06 /* Public */,
       6,    4,  158,    2, 0x06 /* Public */,
      11,    2,  167,    2, 0x06 /* Public */,
      14,    2,  172,    2, 0x06 /* Public */,
      15,    3,  177,    2, 0x06 /* Public */,
      19,    1,  184,    2, 0x06 /* Public */,
      20,    1,  187,    2, 0x06 /* Public */,
      22,    1,  190,    2, 0x06 /* Public */,
      24,    1,  193,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
      25,    0,  196,    2, 0x0a /* Public */,
      26,    0,  197,    2, 0x0a /* Public */,
      27,    0,  198,    2, 0x0a /* Public */,
      28,    1,  199,    2, 0x0a /* Public */,
      30,    0,  202,    2, 0x0a /* Public */,
      31,    0,  203,    2, 0x0a /* Public */,
      32,    0,  204,    2, 0x0a /* Public */,
      33,    1,  205,    2, 0x0a /* Public */,
      35,    1,  208,    2, 0x0a /* Public */,
      36,    0,  211,    2, 0x0a /* Public */,
      37,    1,  212,    2, 0x0a /* Public */,
      38,    0,  215,    2, 0x0a /* Public */,
      39,    1,  216,    2, 0x09 /* Protected */,
      41,    0,  219,    2, 0x09 /* Protected */,
      42,    0,  220,    2, 0x09 /* Protected */,
      43,    0,  221,    2, 0x09 /* Protected */,
      44,    0,  222,    2, 0x08 /* Private */,
      45,    0,  223,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 4,    5,
    QMetaType::Void, QMetaType::Int, QMetaType::Int, QMetaType::Int, QMetaType::Int,    7,    8,    9,   10,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,   12,   13,
    QMetaType::Void, QMetaType::Int, QMetaType::Int,   12,   13,
    QMetaType::Void, 0x80000000 | 16, QMetaType::Int, QMetaType::QPoint,    2,   17,   18,
    QMetaType::Void, QMetaType::Bool,    2,
    QMetaType::Void, 0x80000000 | 21,    2,
    QMetaType::Void, QMetaType::QString,   23,
    QMetaType::Void, QMetaType::Bool,    2,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   29,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Bool,   34,
    QMetaType::Void, QMetaType::Bool,   36,
    QMetaType::Bool,
    QMetaType::Void, QMetaType::Bool,   38,
    QMetaType::Bool,
    QMetaType::Void, QMetaType::Int,   40,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void TerminalView::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        TerminalView *_t = static_cast<TerminalView *>(_o);
        Q_UNUSED(_t)
        switch (_id) {
        case 0: _t->interrupt_signal(); break;
        case 1: _t->keyPressedSignal((*reinterpret_cast< QKeyEvent*(*)>(_a[1]))); break;
        case 2: _t->mouseSignal((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< int(*)>(_a[3])),(*reinterpret_cast< int(*)>(_a[4]))); break;
        case 3: _t->changedFontMetricSignal((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 4: _t->changedContentSizeSignal((*reinterpret_cast< int(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2]))); break;
        case 5: _t->configureRequest((*reinterpret_cast< TerminalView*(*)>(_a[1])),(*reinterpret_cast< int(*)>(_a[2])),(*reinterpret_cast< const QPoint(*)>(_a[3]))); break;
        case 6: _t->isBusySelecting((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 7: _t->sendStringToEmu((*reinterpret_cast< const char*(*)>(_a[1]))); break;
        case 8: _t->tripleClicked((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 9: _t->set_global_shortcuts_signal((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 10: _t->processFilters(); break;
        case 11: _t->updateImage(); break;
        case 12: _t->updateLineProperties(); break;
        case 13: _t->copyClipboard((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 14: _t->pasteClipboard(); break;
        case 15: _t->pasteSelection(); break;
        case 16: _t->selectAll(); break;
        case 17: _t->outputSuspended((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 18: _t->setUsesMouse((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 19: { bool _r = _t->usesMouse();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 20: _t->setBracketedPasteMode((*reinterpret_cast< bool(*)>(_a[1]))); break;
        case 21: { bool _r = _t->bracketedPasteMode();
            if (_a[0]) *reinterpret_cast< bool*>(_a[0]) = std::move(_r); }  break;
        case 22: _t->scrollBarPositionChanged((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 23: _t->blinkEvent(); break;
        case 24: _t->blinkCursorEvent(); break;
        case 25: _t->enableBell(); break;
        case 26: _t->swapColorTable(); break;
        case 27: _t->tripleClickTimeout(); break;
        default: ;
        }
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        switch (_id) {
        default: *reinterpret_cast<int*>(_a[0]) = -1; break;
        case 5:
            switch (*reinterpret_cast<int*>(_a[1])) {
            default: *reinterpret_cast<int*>(_a[0]) = -1; break;
            case 0:
                *reinterpret_cast<int*>(_a[0]) = qRegisterMetaType< TerminalView* >(); break;
            }
            break;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            typedef void (TerminalView::*_t)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&TerminalView::interrupt_signal)) {
                *result = 0;
                return;
            }
        }
        {
            typedef void (TerminalView::*_t)(QKeyEvent * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&TerminalView::keyPressedSignal)) {
                *result = 1;
                return;
            }
        }
        {
            typedef void (TerminalView::*_t)(int , int , int , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&TerminalView::mouseSignal)) {
                *result = 2;
                return;
            }
        }
        {
            typedef void (TerminalView::*_t)(int , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&TerminalView::changedFontMetricSignal)) {
                *result = 3;
                return;
            }
        }
        {
            typedef void (TerminalView::*_t)(int , int );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&TerminalView::changedContentSizeSignal)) {
                *result = 4;
                return;
            }
        }
        {
            typedef void (TerminalView::*_t)(TerminalView * , int , const QPoint & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&TerminalView::configureRequest)) {
                *result = 5;
                return;
            }
        }
        {
            typedef void (TerminalView::*_t)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&TerminalView::isBusySelecting)) {
                *result = 6;
                return;
            }
        }
        {
            typedef void (TerminalView::*_t)(const char * );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&TerminalView::sendStringToEmu)) {
                *result = 7;
                return;
            }
        }
        {
            typedef void (TerminalView::*_t)(const QString & );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&TerminalView::tripleClicked)) {
                *result = 8;
                return;
            }
        }
        {
            typedef void (TerminalView::*_t)(bool );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&TerminalView::set_global_shortcuts_signal)) {
                *result = 9;
                return;
            }
        }
    }
}

const QMetaObject TerminalView::staticMetaObject = {
    { &QWidget::staticMetaObject, qt_meta_stringdata_TerminalView.data,
      qt_meta_data_TerminalView,  qt_static_metacall, nullptr, nullptr}
};


const QMetaObject *TerminalView::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *TerminalView::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_TerminalView.stringdata0))
        return static_cast<void*>(this);
    return QWidget::qt_metacast(_clname);
}

int TerminalView::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QWidget::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 28)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 28;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 28)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 28;
    }
    return _id;
}

// SIGNAL 0
void TerminalView::interrupt_signal()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}

// SIGNAL 1
void TerminalView::keyPressedSignal(QKeyEvent * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 1, _a);
}

// SIGNAL 2
void TerminalView::mouseSignal(int _t1, int _t2, int _t3, int _t4)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)), const_cast<void*>(reinterpret_cast<const void*>(&_t4)) };
    QMetaObject::activate(this, &staticMetaObject, 2, _a);
}

// SIGNAL 3
void TerminalView::changedFontMetricSignal(int _t1, int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 3, _a);
}

// SIGNAL 4
void TerminalView::changedContentSizeSignal(int _t1, int _t2)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)) };
    QMetaObject::activate(this, &staticMetaObject, 4, _a);
}

// SIGNAL 5
void TerminalView::configureRequest(TerminalView * _t1, int _t2, const QPoint & _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)), const_cast<void*>(reinterpret_cast<const void*>(&_t2)), const_cast<void*>(reinterpret_cast<const void*>(&_t3)) };
    QMetaObject::activate(this, &staticMetaObject, 5, _a);
}

// SIGNAL 6
void TerminalView::isBusySelecting(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 6, _a);
}

// SIGNAL 7
void TerminalView::sendStringToEmu(const char * _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 7, _a);
}

// SIGNAL 8
void TerminalView::tripleClicked(const QString & _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 8, _a);
}

// SIGNAL 9
void TerminalView::set_global_shortcuts_signal(bool _t1)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(&_t1)) };
    QMetaObject::activate(this, &staticMetaObject, 9, _a);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
